@@ -1,4 +1,4 @@
-`ardec.trend` <-
+ardec.trend <-
 function(x){
 
 options(warn=-1)
@@ -26,4 +26,3 @@ return(list(modulus=m,trend=gt))
 
 
 }
-
